@@ -1,12 +1,12 @@
 package Getopt::Long::Subcommand;
 
-our $DATE = '2015-02-12'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-03-09'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 require Exporter;
 our @ISA = qw(Exporter);
@@ -49,17 +49,17 @@ sub _gl_getoptions {
     require Getopt::Long;
 
     my ($ospec, $pass_through) = @_;
-    $log->tracef('Performing Getopt::Long::GetOptions');
+    $log->tracef('[comp][glsubc] Performing Getopt::Long::GetOptions');
 
     my $old_conf = Getopt::Long::Configure(
         'no_ignore_case', 'bundling',
         ('pass_through') x !!$pass_through,
     );
     local $SIG{__WARN__} = sub {} if $pass_through;
-    $log->tracef('@ARGV before Getopt::Long::GetOptions: %s', \@ARGV);
-    $log->tracef('spec for Getopt::Long::GetOptions: %s', $ospec);
+    $log->tracef('[comp][glsubc] @ARGV before Getopt::Long::GetOptions: %s', \@ARGV);
+    $log->tracef('[comp][glsubc] spec for Getopt::Long::GetOptions: %s', $ospec);
     my $gl_res = Getopt::Long::GetOptions(%$ospec);
-    $log->tracef('@ARGV after  Getopt::Long::GetOptions: %s', \@ARGV);
+    $log->tracef('[comp][glsubc] @ARGV after  Getopt::Long::GetOptions: %s', \@ARGV);
     Getopt::Long::Configure($old_conf);
     $gl_res;
 }
@@ -76,7 +76,7 @@ sub _GetOptions {
     # check command spec
     {
         use experimental 'smartmatch';
-        $log->tracef("Checking cmdspec keys: %s", [keys %$cmdspec]);
+        $log->tracef("[comp][glsubc] Checking cmdspec keys: %s", [keys %$cmdspec]);
         for (keys %$cmdspec) {
             $_ ~~ @known_cmdspec_keys
                 or die "Unknown command specification key '$_'" .
@@ -146,8 +146,9 @@ sub _GetOptions {
     }
     $res->{success} //= 1;
 
-    $log->tracef('Final @ARGV: %s', \@ARGV) unless $stash->{path};
-    $log->tracef('TMP: stash=%s', $stash);
+    $log->tracef('[comp][glsubc] Final @ARGV: %s', \@ARGV) unless $stash->{path};
+    #$log->tracef('[comp][glsubc] TMP: stash=%s', $stash);
+    #$log->tracef('[comp][glsubc] TMP: res=%s', $res);
     $res;
 }
 
@@ -214,7 +215,7 @@ sub GetOptions {
                 }
 
                 $args{getopt_res} = $res;
-                $args{subcommand} = $res->{comp_subcommand_name}[-1];
+                $args{subcommand} = $res->{comp_subcommand_name};
                 $cmdspec{completion}->(%args) if $cmdspec{completion};
             },
         );
@@ -250,7 +251,7 @@ Getopt::Long::Subcommand - Process command-line options, with subcommands and co
 
 =head1 VERSION
 
-This document describes version 0.02 of Getopt::Long::Subcommand (from Perl distribution Getopt-Long-Subcommand), released on 2015-02-12.
+This document describes version 0.03 of Getopt::Long::Subcommand (from Perl distribution Getopt-Long-Subcommand), released on 2015-03-09.
 
 =head1 SYNOPSIS
 
